@@ -40,3 +40,6 @@ class OpeningHoursWidget(Widget):
             opening_hours = OpeningHours.objects.get(pk=value)
             context["widget"]["instance"] = opening_hours
         return context
+
+    class Media:
+        js = ["admin/js/RelatedOpeningHoursLookups.js"]
